==> kipi-plugins-23.04.1.tar.xz: kipi-plugins-23.04.1/googleservices/kipiplugin_googleservices.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Google Services
Name=Google Services
Name[bg]=Услуги на Google
Name[ca]=Serveis de Google
Name[ca@valencia]=Serveis de Google
Name[cs]=Služby Google
Name[da]=Google-tjenester
Name[de]=Google Services
Name[el]=Google Services
Name[en_GB]=Google Services
Name[es]=Servicios de Google
Name[et]=Google'i teenused
Name[eu]=Google-ra esportatzea
Name[fi]=Google Services
Name[fr]=Services Google
Name[gl]=Servizos de Google
Name[hu]=Google szolgáltatások
Name[ia]=Google Services (Servicios de Google)
Name[id]=Google Services
Name[is]=Google þjónustur
Name[it]=Servizi di Google
Name[ka]=Google-ის სერვისები
Name[ko]=Google 서비스
Name[nl]=Google Services
Name[nn]=Google-tenester
Name[pl]=Usługi Google
Name[pt]=Serviços do Google
Name[pt_BR]=Serviços do Google
Name[ro]=Servicii Google
Name[ru]=Службы Google
Name[sk]=Google služby
Name[sl]=Storitve Google
Name[sv]=Google-tjänster
Name[tr]=Google Servisleri
Name[uk]=Служби Google
Name[x-test]=xxGoogle Servicesxx
Name[zh_CN]=Google 服务
Name[zh_TW]=Google 服務
Comment=A tool to manage images with a remote Google web service
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Google
Comment[ca]=Una eina per a gestionar les imatges amb un servei web remot de Google
Comment[ca@valencia]=Una eina per a gestionar les imatges amb un servei web remot de Google
Comment[cs]=Nástroj pro správu obrázků vzdálené webové služby Google
Comment[da]=Et værktøj til at håndtere billeder med en ekstern webbaseret Google-tjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Google-Webdienst zu verwalten.
Comment[el]=Εργαλείο διαχείρισης εικόνων σε μια απομακρυσμένη υπηρεσία ιστού της Google
Comment[en_GB]=A tool to manage images with a remote Google web service
Comment[es]=Una herramienta para la gestión de imágenes con un servicio remoto de Google
Comment[et]=Tööriist piltide haldamiseks Google' veebiteenuses
Comment[eu]=Irudiak urruneko Google web zerbitzu batekin kudeatzeko tresna bat
Comment[fi]=Työkalu kuvien hallitsemiseen Googlen verkkopalvelulla
Comment[fr]=Outil d'export d'images vers un service web Google
Comment[gl]=Unha ferramenta para xestionar imaxes cun servizo web de Google remoto.
Comment[hu]=Egy eszköz képek exportálásához egy távoli Google webszolgáltatásba
Comment[id]=Sebuah alat untuk mengekspor citra dengan layanan web Google jarak jauh
Comment[is]=Verkfæri til að sýsla með myndir á fjartengdri Google vefþjónustu
Comment[it]=Uno strumento per gestire immagini con un servizio web remoto di Google
Comment[ka]=პროგრამა სურათების დაშორებულ Google -ის ვებსერვისზე გასატანად
Comment[ko]=원격 Google 웹 서비스의 사진을 관리하는 도구
Comment[nl]=Een hulpmiddel om afbeeldingen met een Google Services-webservice te beheren
Comment[nn]=Verktøy for handsaming av bilete med Google-tenesta på nettet.
Comment[pl]=Narzędzie do zarządzania obrazami przy użyciu zdalnej usługi sieciowej Google
Comment[pt]=Uma ferramenta para gerir imagens com um dos serviços Web remotos da Google
Comment[pt_BR]=Ferramenta para gerenciar imagens com os serviços do Google
Comment[ro]=Unealtă de gestionat imagini cu un serviciu web distant Google
Comment[ru]=Инструмент для управления изображениями, расположенными веб-службах серверах Google
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu webovú Google
Comment[sl]=Orodje za upravljanje slik z oddaljeno spletno storitvijo Google
Comment[sv]=Ett verktyg för att hantera bilder med en Google webbtjänst
Comment[tr]=Görselleri uzak bir Google Drive web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для керування зображеннями за допомогою віддаленої служби Google
Comment[x-test]=xxA tool to manage images with a remote Google web servicexx
Comment[zh_CN]=一个管理图像的工具，使用 Google网络服务
Comment[zh_TW]=透過 Google 網路服務管理圖片的工具
Type=Service
Icon=kipi-googledrive
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_googleservices
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Saurabh Patel, saurabhpatel7717 at gmail dot com

==> kipi-plugins-23.08.4.tar.xz: kipi-plugins-23.08.4/googleservices/kipiplugin_googleservices.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Google Services
Name=Google Services
Name[bg]=Услуги на Google
Name[ca]=Serveis de Google
Name[ca@valencia]=Serveis de Google
Name[cs]=Služby Google
Name[da]=Google-tjenester
Name[de]=Google Services
Name[el]=Google Services
Name[en_GB]=Google Services
Name[eo]=Servoj de Google
Name[es]=Servicios de Google
Name[et]=Google'i teenused
Name[eu]=Google-ra esportatzea
Name[fi]=Google Services
Name[fr]=Services Google
Name[gl]=Servizos de Google
Name[hu]=Google szolgáltatások
Name[ia]=Google Services (Servicios de Google)
Name[id]=Google Services
Name[is]=Google þjónustur
Name[it]=Servizi di Google
Name[ka]=Google-ის სერვისები
Name[ko]=Google 서비스
Name[nl]=Google Services
Name[nn]=Google-tenester
Name[pl]=Usługi Google
Name[pt]=Serviços do Google
Name[pt_BR]=Serviços do Google
Name[ro]=Servicii Google
Name[ru]=Службы Google
Name[sk]=Google služby
Name[sl]=Storitve Google
Name[sv]=Google-tjänster
Name[tr]=Google Hizmetleri
Name[uk]=Служби Google
Name[x-test]=xxGoogle Servicesxx
Name[zh_CN]=Google 服务
Name[zh_TW]=Google 服務
Comment=A tool to manage images with a remote Google web service
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Google
Comment[ca]=Una eina per a gestionar les imatges amb un servei web remot de Google
Comment[ca@valencia]=Una eina per a gestionar les imatges amb un servei web remot de Google
Comment[cs]=Nástroj pro správu obrázků vzdálené webové služby Google
Comment[da]=Et værktøj til at håndtere billeder med en ekstern webbaseret Google-tjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Google-Webdienst zu verwalten.
Comment[el]=Εργαλείο διαχείρισης εικόνων σε μια απομακρυσμένη υπηρεσία ιστού της Google
Comment[en_GB]=A tool to manage images with a remote Google web service
Comment[eo]=Ilo por administri bildojn per fora Gugla retservo
Comment[es]=Una herramienta para la gestión de imágenes con un servicio remoto de Google
Comment[et]=Tööriist piltide haldamiseks Google' veebiteenuses
Comment[eu]=Irudiak urruneko Google web zerbitzu batekin kudeatzeko tresna bat
Comment[fi]=Työkalu kuvien hallitsemiseen Googlen verkkopalvelulla
Comment[fr]=Outil d'export d'images vers un service web Google
Comment[gl]=Unha ferramenta para xestionar imaxes cun servizo web de Google remoto.
Comment[hu]=Egy eszköz képek exportálásához egy távoli Google webszolgáltatásba
Comment[id]=Sebuah alat untuk mengekspor citra dengan layanan web Google jarak jauh
Comment[is]=Verkfæri til að sýsla með myndir á fjartengdri Google vefþjónustu
Comment[it]=Uno strumento per gestire immagini con un servizio web remoto di Google
Comment[ka]=პროგრამა სურათების დაშორებულ Google -ის ვებსერვისზე გასატანად
Comment[ko]=원격 Google 웹 서비스의 사진을 관리하는 도구
Comment[nl]=Een hulpmiddel om afbeeldingen met een Google Services-webservice te beheren
Comment[nn]=Verktøy for handsaming av bilete med Google-tenesta på nettet.
Comment[pl]=Narzędzie do zarządzania obrazami przy użyciu zdalnej usługi sieciowej Google
Comment[pt]=Uma ferramenta para gerir imagens com um dos serviços Web remotos da Google
Comment[pt_BR]=Ferramenta para gerenciar imagens com os serviços do Google
Comment[ro]=Unealtă de gestionat imagini cu un serviciu web distant Google
Comment[ru]=Инструмент для управления изображениями, расположенными веб-службах серверах Google
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu webovú Google
Comment[sl]=Orodje za upravljanje slik z oddaljeno spletno storitvijo Google
Comment[sv]=Ett verktyg för att hantera bilder med en Google webbtjänst
Comment[tr]=Görselleri uzak bir Google Drive web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для керування зображеннями за допомогою віддаленої служби Google
Comment[x-test]=xxA tool to manage images with a remote Google web servicexx
Comment[zh_CN]=一个管理图像的工具，使用 Google网络服务
Comment[zh_TW]=透過 Google 網路服務管理圖片的工具
Type=Service
Icon=kipi-googledrive
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_googleservices
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Saurabh Patel, saurabhpatel7717 at gmail dot com
